@@ -30,7 +30,7 @@ sub has_happened {
 sub happen {
     my ($self, $evt) = @_;
 
-    diag "EVENT HAPPENING: $evt";
+    # diag "EVENT HAPPENING: $evt";
 
     sysopen my $fh, "$self->{'_tempdir'}/event_$evt", Fcntl::O_WRONLY | Fcntl::O_CREAT | Fcntl::O_EXCL;
 
